==========
Developers
==========

* Magdalena Rother <rother.magdalena@gmail.com>
* Sebastian Thieme <thieme.sebastian@gmail.com>
* Ulrike Münzner <ulrike.muenzner@biologie.hu-berlin.de>
* Marcus Krantz <marcus.krantz@biologie.hu-berlin.de>
